@@ -15,9 +15,8 @@ class SplTokenViewerApiClient(object):
         return responses
 
     def fetch_nfts_from_wallet_address(self, address):
+        url = '{}fetch_nft_data'.format(self.base_url)
         params = {'address': address}
-        response = requests.get(
-            '{}/fetch_nft_data'.format(self.base_url),
-            data=params)
-        return response.json()
+        response = requests.get(url,params=params)
+        return response.json()['nfts']
 
